.. Python Darwin Core Archive documentation master file, created by
   sphinx-quickstart on Mon Jan 29 16:48:01 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Python Darwin Core Archive's documentation!
======================================================

This library was implemented to contribute to the ecological and bioinformatics community to help automate the process of standardize biodiversity data using Python.

The principal purpose of this package is:

- To work with Darwin Core Archive files using the data analytics tool of Python. Facilitating the importing of this data to be processed using Python scripts or Jupyter Notebooks.
- To generate a standard and sharable file to the biodiversity research community from data in other formats (like relational database) using Python.

This code was implemented following the specifications of the `Darwin Core Archive guide <https://dwc.tdwg.org/text/>`_ and the `Ecological Metadata Language Specifications <https://eml.ecoinformatics.org/>`_.

Use cases, possible needed features or bug reports are welcome and encourage using our `GitHub Issues Page <https://github.com/IEB-BIODATA/pydwca/issues>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   usage
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
